@@ -8,38 +8,39 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-# $Id: Random.pm,v 1.3 2006/04/20 22:09:35 steve Exp $
+# $Id: Random.pm,v 1.4 2006/09/21 17:34:07 steve Exp $
 
 package String::Random;
 
+require 5.006_001;
+
 use strict;
 use warnings;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-
+use Carp;
 use Exporter ();
 
-@ISA = qw(Exporter);
-@EXPORT_OK = qw(random_string random_regex);
-$VERSION = '0.21';
-
-use Carp;
-
-use vars qw(@upper @lower @digit @punct @any @salt @binary);
-use vars qw(%old_patterns %patterns %regch);
+our @ISA = qw(Exporter);
+our %EXPORT_TAGS = ( 'all' => [ qw(
+    &random_string
+    &random_regex
+) ] );
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+our @EXPORT = ();
+our $VERSION = '0.23';
 
 # These are the various character sets.
-@upper=("A".."Z");
-@lower=("a".."z");
-@digit=("0".."9");
-@punct=map { chr($_); } (33..47,58..64,91..96,123..126);
-@any=(@upper, @lower, @digit, @punct);
-@salt=(@upper, @lower, @digit, ".", "/");
-@binary=map { chr($_) } (0..255);
+our @upper=("A".."Z");
+our @lower=("a".."z");
+our @digit=("0".."9");
+our @punct=map { chr($_); } (33..47,58..64,91..96,123..126);
+our @any=(@upper, @lower, @digit, @punct);
+our @salt=(@upper, @lower, @digit, ".", "/");
+our @binary=map { chr($_) } (0..255);
 
 # What's important is how they relate to the pattern characters.
 # These are the old patterns for randpattern/random_string.
-%old_patterns = (
+our %old_patterns = (
     'C' => [ @upper ],
     'c' => [ @lower ],
     'n' => [ @digit ],
@@ -50,7 +51,7 @@ use vars qw(%old_patterns %patterns %regch);
 );
 
 # These are the regex-based patterns.
-%patterns = (
+our %patterns = (
     # These are the regex-equivalents.
     '.' => [ @any ],
     '\d' => [ @digit ],
@@ -70,7 +71,7 @@ use vars qw(%old_patterns %patterns %regch);
 );
 
 # These characters are treated specially in randregex().
-%regch = (
+our %regch = (
    "\\" => sub {
                my ($self, $ch, $chars, $string)=@_;
                if (@{$chars}) {
@@ -86,8 +87,11 @@ use vars qw(%old_patterns %patterns %regch);
                    } elsif (defined($patterns{"\\$tmp"})) {
                        $ch.=$tmp;
                        push(@{$string}, $patterns{$ch});
-                   } else {
-                       carp "'\\$tmp' being treated as literal '$tmp'";
+                   }
+                   else {
+                       if ($tmp =~ /\w/) {
+                           carp "'\\$tmp' being treated as literal '$tmp'";
+                       }
                        push(@{$string}, [$tmp]);
                    }
                } else {
@@ -278,22 +282,25 @@ sub random_string {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 String::Random - Perl module to generate random strings based on a pattern
 
 =head1 SYNOPSIS
 
-  use String::Random;
-  $foo = new String::Random;
-  print $foo->randregex('\d\d\d'); # Prints 3 random digits
-  print $foo->randpattern("...");  # Prints 3 random printable characters
+    use String::Random;
+    my $string_gen = String::Random->new;
+    print $string_gen->randregex('\d\d\d'); # Prints 3 random digits
+    # Prints 3 random printable characters
+    print $string_gen->randpattern("...");
 
 I<or>
 
-  use String::Random qw(random_regex random_string);
-  print random_regex('\d\d\d'); # Also prints 3 random digits
-  print random_string("...");   # Also prints 3 random printable characters
+    use String::Random qw(random_regex random_string);
+    print random_regex('\d\d\d'); # Also prints 3 random digits
+    print random_string("...");   # Also prints 3 random printable characters
 
 =head1 DESCRIPTION
 
@@ -303,19 +310,22 @@ As an example, let's say you are writing a script that needs to generate a
 random password for a user.  The relevant code might look something like
 this:
 
-  use String::Random;
-  $pass = new String::Random;
-  print "Your password is ", $pass->randpattern("CCcc!ccn"), "\n";
+    use String::Random;
+    my $pass = String::Random->new;
+    print "Your password is ", $pass->randpattern("CCcc!ccn"), "\n";
 
 This would output something like this:
 
   Your password is UDwp$tj5
 
+B<NOTE!!!>: currently, String::Random uses Perl's built-in predictable random
+number generator so the passwords generated by it are insecure.
+
 If you are more comfortable dealing with regular expressions, the following
 code would have a similar result:
 
   use String::Random;
-  $pass = new String::Random;
+  my $pass = String::Random->new;
   print "Your password is ",
       $pass->randregex('[A-Z]{2}[a-z]{2}.[a-z]{2}\d'), "\n";
 
@@ -324,8 +334,8 @@ code would have a similar result:
 The pre-defined patterns (for use with C<randpattern()> and C<random_pattern()>)
 are as follows:
 
-  c        Any lowercase character [a-z]
-  C        Any uppercase character [A-Z]
+  c        Any Latin lowercase character [a-z]
+  C        Any Latin uppercase character [A-Z]
   n        Any digit [0-9]
   !        A punctuation character [~`!@$%^&*()-_+={}[]|\:;"'.<>?/#,]
   .        Any of the above
@@ -337,13 +347,13 @@ create another pattern, possibly using one of the pre-defined as a base.
 For example, if you wanted a pattern C<A> that contained all upper and lower
 case letters (C<[A-Za-z]>), the following would work:
 
-  $foo = new String::Random;
-  $foo->{'A'} = [ 'A'..'Z', 'a'..'z' ];
+  my $gen = String::Random->new;
+  $gen->{'A'} = [ 'A'..'Z', 'a'..'z' ];
 
 I<or>
 
-  $foo = new String::Random;
-  $foo->{'A'} = [ @{$foo->{'C'}}, @{$foo->{'c'}} ];
+  my $gen = String::Random->new;
+  $gen->{'A'} = [ @{$gen->{'C'}}, @{$gen->{'c'}} ];
 
 The random_string function, described below, has an alternative interface
 for adding patterns.
@@ -359,8 +369,8 @@ for adding patterns.
 Create a new String::Random object.
 
 Optionally a parameter C<max> can be included to specify the maximum number
-of characters to return for C<*> and other regular expression patters that
-don't return a fixed number of characters.
+of characters to return for C<*> and other regular expression patterns that
+do not return a fixed number of characters.
 
 =item randpattern LIST
 
@@ -412,27 +422,34 @@ containing other patterns can be passed to the function.  Those lists will
 be used for 0 through 9 in the pattern (meaning the maximum number of lists
 that can be passed is 10).  For example, the following code:
 
-  print random_string("0101",
-                      ["a", "b", "c"],
-                      ["d", "e", "f"]), "\n";
+    print random_string("0101",
+                        ["a", "b", "c"],
+                        ["d", "e", "f"]), "\n";
 
 would print something like this:
 
-  cebd
+    cebd
 
 =back
 
 =head1 BUGS
 
-This is Bug Free(TM) code.  (At least until somebody finds one...)
+This is Bug Free™ code.  (At least until somebody finds one…)
+
+Please report bugs here:
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=String-Random> .
 
 =head1 AUTHOR
 
-Steven Pritchard <steve@silug.org>
+Original Author: Steven Pritchard C<< steve@silug.org >>
+
+Now maintained by: Shlomi Fish ( L<http://www.shlomifish.org/> ).
 
 =head1 SEE ALSO
 
 perl(1).
 
 =cut
+
 # vi: set ai et:
